/*-------------------------------------------------------------*/
/*-------------------------------------------------------------*/
/*-------------BASE DE DATOS VISTA ESTÁTICA KUALI-BEH----------*/
/*-------------------------------------------------------------*/
/*------------UNIVERSIDAD NACIONAL AUTÓNOMA DE MÉXICO----------*/
/*-------------------------------------------------------------*/
/*------------AUTOR: RODRIGO ALBERTO BARRERA HERNÁNDEZ---------*/
/*-------------------------------------------------------------*/
/*-------------------------------------------------------------*/
/*-------------------POSTGRESQL 9.2------------------------------*/
/*-------------------------------------------------------------*/
/*-----------------BORRADO DE BASE DE DATOS--------------------*/
DROP DATABASE KUALIBEH;
/*-------------------------------------------------------------*/
/*-------------------------------------------------------------*/
/*---------------CREACIÓN DE LA BASE DE DATOS------------------*/
CREATE DATABASE KUALIBEH;
/*-------------------------------------------------------------*/
/*-------------------------------------------------------------*/
USE KUALIBEH;
/*-------------------------------------------------------------*/
/*-------------------------------------------------------------*/
/*--------------------BORRADO DE TABLAS------------------------*/
/*1*/	DROP TABLE IF EXISTS GUIDE_ACTIVITY;
/*2*/	DROP TABLE IF EXISTS ACTIVITY_TOOL;
/*3*/	DROP TABLE IF EXISTS TOOL;
/*4*/	DROP TABLE IF EXISTS TYPE;
/*5*/	DROP TABLE IF EXISTS ACTIVITY_KNOWLEDGESKILLS;
/*6*/	DROP TABLE IF EXISTS KNOWLEDGESKILLS;
/*7*/	DROP TABLE IF EXISTS METHOD_PRACTICE;
/*8*/	DROP TABLE IF EXISTS METHOD_IO;
/*9*/	DROP TABLE IF EXISTS PRACTICE_IO;
/*10*/	DROP TABLE IF EXISTS METHOD;
/*11*/	DROP TABLE IF EXISTS ACTIVITY_TASK;
/*12*/	DROP TABLE IF EXISTS TASK;
/*13*/	DROP TABLE IF EXISTS ACTIVITY_MEASURE;
/*14*/	DROP TABLE IF EXISTS ACTIVITY_IO;
/*15*/	DROP TABLE IF EXISTS MEASURE;
/*16*/	DROP TABLE IF EXISTS WP_C;
/*17*/	DROP TABLE IF EXISTS WORK_PRODUCT;
/*18*/	DROP TABLE IF EXISTS ACTIVITY_VC;
/*19*/	DROP TABLE IF EXISTS VERIFICATION_CRITERIA;
/*20*/	DROP TABLE IF EXISTS GUIDE;
/*21*/	DROP TABLE IF EXISTS PRACTICE;
/*22*/	DROP TABLE IF EXISTS FAMILY;
/*23*/	DROP TABLE IF EXISTS ACTIVITY;
/*24*/	DROP TABLE IF EXISTS CHARACTERISTICS;
/*-------------------------------------------------------------*/
/*--------------------CREACIÓN DE TABLAS-----------------------*/
/*-------------------------------------------------------------*/
/*-------------------------------------------------------------*/
/*------------------CREACIÓN TABLA FAMILY----------------------*/
CREATE TABLE FAMILY(
	id_family		varchar not null PRIMARY KEY,
	name			varchar not null,
	description		varchar not null
);
/*-------------------------------------------------------------*/
/*------------------CREACIÓN TABLA METHOD----------------------*/
CREATE TABLE METHOD(
	id_method		    varchar not null,
	version				varchar not null,
	name				varchar not null,
	purpose				varchar not null,
	fechaCaptura		timestamp,
	PRIMARY KEY (id_method, version)
);
/*-------------------------------------------------------------*/
/*-----------------CREACIÓN TABLA PRACTICE---------------------*/
CREATE TABLE PRACTICE (
	id_practice		    varchar not null,
	version				varchar not null,
	name				varchar not null,
	objetive			varchar not null,
	fechaCaptura		timestamp,
	PRIMARY KEY (id_practice, version)
);
/*-------------------------------------------------------------*/
/*-----------------CREACIÓN TABLA METHOD_PRACTICE--------------*/
CREATE TABLE METHOD_PRACTICE(
	id_method				varchar not null,
	version_m				varchar not null,
	id_practice				varchar not null,
	version_p				varchar not null,
	PRIMARY KEY (id_method, version_m, id_practice, version_p)
);
/*-------------------------------------------------------------*/
/*---------------CREACIÓN TABLA WORK_PRODUCT-------------------*/
CREATE TABLE WORK_PRODUCT(
	id_wp				varchar not null PRIMARY KEY,
	nombre				varchar not null
);
/*-------------------------------------------------------------*/
/*-------------CREACIÓN TABLA CHARACTERISTICS------------------*/
CREATE TABLE CHARACTERISTICS(
	id_chars			varchar not null PRIMARY KEY,
	tipo				varchar not null,
	feature		varchar not null
);
/*-------------------------------------------------------------*/
/*-----------------CREACIÓN TABLA CWP_C------------------------*/
CREATE TABLE WP_C(
	id_wp		varchar not null,
	id_chars	varchar,
	PRIMARY KEY (id_wp, id_chars)
);
/*-------------------------------------------------------------*/
/*---------------CREACIÓN TABLA KNOWLEDGESKILLS----------------*/
CREATE TABLE KNOWLEDGESKILLS(
	id_ks			varchar not null PRIMARY KEY,
	name			varchar not null,
	description		varchar not null
);
/*-------------------------------------------------------------*/
/*-----------------CREACIÓN TABLA TASK-------------------------*/
CREATE TABLE TASK(
	id_task			varchar not null PRIMARY KEY,
	description		varchar not null
);
/*-------------------------------------------------------------*/
/*--------------- CREACIÓN TABLA ACTIVITY----------------------*/
CREATE TABLE ACTIVITY(
	id_activity		varchar not null PRIMARY KEY,
	name			varchar not null,
	description		varchar not null
);
/*-------------------------------------------------------------*/
/*-------------CREACIÓN TABLA VERIFICATION_CRITERIA------------*/
CREATE TABLE VERIFICATION_CRITERIA(
	id_vc			varchar not null PRIMARY KEY,
	description		varchar not null
);
/*-------------------------------------------------------------*/
/*-----------------CREACIÓN TABLA MEASURE----------------------*/
CREATE TABLE MEASURE(
	id_measure			varchar not null PRIMARY KEY,
	description			varchar not null
);
/*-------------------------------------------------------------*/
/*--------------------CREACIÓN TABLA TOOL----------------------*/
CREATE TABLE TOOL(
	id_tool						varchar not null PRIMARY KEY,
	name						varchar not null,
	version						varchar not null,
	description					varchar not null,
	url							varchar not null,
	technical_specification		varchar not null,
	id_type						varchar
);
/*-------------------------------------------------------------*/
/*---------------------CREACIÓN TABLA TYPE---------------------*/
CREATE TABLE TYPE(
	id_type				varchar not null PRIMARY KEY,
	nombre				varchar not null
);
/*-------------------------------------------------------------*/
/*----------------CREACIÓN TABLA GUIDE_KNOWLEDGESKILLS---------*/
CREATE TABLE ACTIVITY_KNOWLEDGESKILLS(
	id_activity			varchar not null,
	id_ks				varchar not null,
	PRIMARY KEY (id_activity, id_ks)
);
/*-------------------------------------------------------------*/
/*--------------------CREACIÓN TABLA ACTIVITY_TASK-------------*/
CREATE TABLE ACTIVITY_TASK(
	id_activity			varchar not null,
	id_task				varchar not null,
	PRIMARY KEY (id_activity, id_task)
);
/*-------------------------------------------------------------*/
/*---------------------CREACIÓN TABLA ACTIVITY_IO--------------*/
CREATE TABLE ACTIVITY_IO(
	id_activity				varchar not null,
	id_chars				varchar not null,
	input_result			char not null,
	PRIMARY KEY (id_activity, id_chars, input_result)
);
/*-------------------------------------------------------------*/
/*--------------------CREACIÓN TABLA ACTIVITY_VC---------------*/
CREATE TABLE ACTIVITY_VC(
	id_activity		varchar not null,
	id_vc			varchar not null,
	PRIMARY KEY (id_activity, id_vc)
);
/*-------------------------------------------------------------*/
/*-------------------CREACIÓN TABLA ACTIVITY_MEASURE-----------*/
CREATE TABLE ACTIVITY_MEASURE(
	id_activity		varchar not null,
	id_measure		varchar not null,
	PRIMARY KEY (id_activity, id_measure)
);
/*-------------------------------------------------------------*/
/*-------------------CREACIÓN TABLA ACTIVITY_TOOL--------------*/
CREATE TABLE ACTIVITY_TOOL(
	id_activity		varchar not null,
	id_tool			varchar not null,
	PRIMARY KEY (id_activity, id_tool)
);
/*-------------------------------------------------------------*/
/*---------------------CREACIÓN TABLA GUIDE--------------------*/
CREATE TABLE GUIDE(
	id_guide		serial PRIMARY KEY,
	name			varchar,
	version			varchar,
	fechaCaptura	timestamp,
	id_practice		varchar,
	version_p		varchar
);
/*-------------------------------------------------------------*/
/*-----------------CREACIÓN TABLA GUIDE_ACTIVITY---------------*/
CREATE TABLE GUIDE_ACTIVITY(
	id_guide		integer not null,
	id_activity		varchar not null,
	PRIMARY KEY (id_guide, id_activity)
);
/*-------------------------------------------------------------*/
/*------------------CREACIÓN TABLA PRACTICE_IO-----------------*/
CREATE TABLE PRACTICE_IO(
	id_practice				varchar not null,
	version					varchar not null,
	id_chars				varchar not null,
	input_result			char not null,
	PRIMARY KEY (id_practice, version, id_chars, input_result)
);
/*-------------------------------------------------------------*/
/*-------------------CREACIÓN TABLA METHOD_IO------------------*/
CREATE TABLE METHOD_IO(
	id_method				varchar not null,
	version					varchar not null,
	id_chars				varchar not null,
	input_result			char not null,
	PRIMARY KEY (id_method, version, id_chars, input_result)
);
/*-------------------------------------------------------------*/
/*-------------------------------------------------------------*/
/*----------------------FOREING KEY’S--------------------------*/
/*-------------------------------------------------------------*/
/*--MODIFICAR METHOD_PRACTICE FOREING KEY ID_METHOD, VERSION_M-*/
ALTER TABLE METHOD_PRACTICE
	ADD FOREIGN KEY (id_method, version_m)
		REFERENCES METHOD (id_method, version) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*-MODIFICAR METHOD_PRACTICE FOREING KEY ID_PRACTICE, VERSION_P*/
ALTER TABLE METHOD_PRACTICE
	ADD FOREIGN KEY (id_practice, version_p)
		REFERENCES PRACTICE (id_practice, version) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/	
/*-MODIFICAR PRACTICE_GUIDE FOREING KEY ID_PRACTICE, VERSION_P-*/
ALTER TABLE GUIDE
	ADD FOREIGN KEY (id_practice, version_p)
		REFERENCES PRACTICE (id_practice, version) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*---MODIFICAR GUIDE_ACTIVITY FOREING KEY ID_GUIDE, VERSION----*/
ALTER TABLE GUIDE_ACTIVITY
	ADD FOREIGN KEY (id_guide)
		REFERENCES GUIDE (id_guide) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*-----MODIFICAR GUIDE_ACTIVITY FOREING KEY ID_ACTIVITY--------*/
ALTER TABLE GUIDE_ACTIVITY
	ADD FOREIGN KEY (id_activity)
		REFERENCES ACTIVITY (id_activity) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/	
/*------MODIFICAR ACTIVITY_TASK FOREING KEY ID_ACTIVITY--------*/
ALTER TABLE ACTIVITY_TASK
	ADD FOREIGN KEY (id_activity)
		REFERENCES ACTIVITY (id_activity) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*--------MODIFICAR ACTIVITY_TASK FOREING KEY ID_TASK----------*/
ALTER TABLE ACTIVITY_TASK
	ADD FOREIGN KEY (id_task)
		REFERENCES TASK (id_task) ON DELETE CASCADE ON UPDATE CASCADE;		
/*-------------------------------------------------------------*/
/*----------MODIFICAR ACTIVITY_IO FOREING KEY ID_TASK----------*/
ALTER TABLE ACTIVITY_IO
	ADD FOREIGN KEY (id_chars)
		REFERENCES CHARACTERISTICS (id_chars) ON DELETE CASCADE ON UPDATE CASCADE;		
/*-------------------------------------------------------------*/		
/*-----------MODIFICAR ACTIVITY_IO FOREING KEY ID_TASK---------*/
ALTER TABLE ACTIVITY_IO
	ADD FOREIGN KEY (id_activity)
		REFERENCES ACTIVITY (id_activity) ON DELETE CASCADE ON UPDATE CASCADE;	
/*-------------------------------------------------------------*/
/*---------MODIFICAR ACTIVITY_VC FOREING KEY ID_ACTIVITY-------*/
ALTER TABLE ACTIVITY_VC
	ADD FOREIGN KEY (id_activity)
		REFERENCES ACTIVITY (id_activity) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*------------MODIFICAR ACTIVITY_VC FOREING KEY ID_VC----------*/
ALTER TABLE ACTIVITY_VC
	ADD FOREIGN KEY (id_vc)
		REFERENCES VERIFICATION_CRITERIA (id_vc) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/		
/*-------MODIFICAR ACTIVITY_MEASURE FOREING KEY ID_ACTIVITY----*/
ALTER TABLE ACTIVITY_MEASURE
	ADD FOREIGN KEY (id_activity)
		REFERENCES ACTIVITY (id_activity) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*------MODIFICAR ACTIVITY_MEASURE FOREING KEY ID_MEASURE------*/
ALTER TABLE ACTIVITY_MEASURE
	ADD FOREIGN KEY (id_measure)
		REFERENCES MEASURE (id_measure) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/		
/*-------MODIFICAR ACTIVITY_TOOL FOREING KEY ID_ACTIVITY-------*/
ALTER TABLE ACTIVITY_TOOL
	ADD FOREIGN KEY (id_activity)
		REFERENCES ACTIVITY (id_activity) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*-----------MODIFICAR ACTIVITY_TOOL FOREING KEY ID_TOOL-------*/
ALTER TABLE ACTIVITY_TOOL
	ADD FOREIGN KEY (id_tool)
		REFERENCES TOOL (id_tool) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*---MODIFICAR ACTIVITY_KNOWLEDGESKILLS FOREING KEY ID_ACTIVITY*/
ALTER TABLE ACTIVITY_KNOWLEDGESKILLS
	ADD FOREIGN KEY (id_activity)
		REFERENCES ACTIVITY (id_activity) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*-----MODIFICAR ACTIVITY_KNOWLEDGESKILLS FOREING KEY ID_KS----*/
ALTER TABLE ACTIVITY_KNOWLEDGESKILLS
	ADD FOREIGN KEY (id_ks)
		REFERENCES KNOWLEDGESKILLS (id_ks) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/		
/*---------------MODIFICAR WP_C FOREING KEY ID_WP--------------*/
ALTER TABLE WP_C
	ADD FOREIGN KEY (id_wp)
		REFERENCES WORK_PRODUCT (id_wp) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/		
/*--------------MODIFICAR WP_C FOREING KEY ID_CHARS------------*/
ALTER TABLE WP_C
	ADD FOREIGN KEY (id_chars)
		REFERENCES CHARACTERISTICS (id_chars) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/		
/*-----MODIFICAR PRACTICE_IO FOREING KEY ID_PRACTICE, VERSION--*/
ALTER TABLE PRACTICE_IO
	ADD FOREIGN KEY (id_practice, version)
		REFERENCES PRACTICE (id_practice, version) ON DELETE CASCADE ON UPDATE CASCADE;		
/*-------------------------------------------------------------*/
/*---------MODIFICAR PRACTICE_IO FOREING KEY ID_TASK-----------*/
ALTER TABLE PRACTICE_IO
	ADD FOREIGN KEY (id_chars)
		REFERENCES CHARACTERISTICS (id_chars) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/		
/*------MODIFICAR METHOD_IO FOREING KEY ID_METHOD, VERSION-----*/
ALTER TABLE METHOD_IO
	ADD FOREIGN KEY (id_method, version)
		REFERENCES METHOD (id_method, version) ON DELETE CASCADE ON UPDATE CASCADE;		
/*-------------------------------------------------------------*/		
/*-----------MODIFICAR METHOD_IO FOREING KEY ID_CHAR-----------*/
ALTER TABLE METHOD_IO
	ADD FOREIGN KEY (id_chars)
		REFERENCES CHARACTERISTICS (id_chars) ON DELETE CASCADE ON UPDATE CASCADE;
/*-------------------------------------------------------------*/
/*-------------------------------------------------------------*/